src/eric7/UI/UserInterface.py

branch
eric7
changeset 9971
773ad1f1ed22
parent 9966
27f2437e6eea
child 10004
983477114d3c
child 10069
435cc5875135
diff -r c3686b43f76b -r 773ad1f1ed22 src/eric7/UI/UserInterface.py
--- a/src/eric7/UI/UserInterface.py	Tue Apr 04 17:26:54 2023 +0200
+++ b/src/eric7/UI/UserInterface.py	Wed Apr 05 11:58:22 2023 +0200
@@ -182,7 +182,7 @@
     @signal reloadAPIs() emitted to reload the api information
     @signal showMenu(str, QMenu) emitted when a menu is about to be shown. The
         name of the menu and a reference to the menu are given.
-    @signal masterPasswordChanged(str, str) emitted after the master
+    @signal mainPasswordChanged(str, str) emitted after the main
         password has been changed with the old and the new password
     @signal onlineStateChanged(online) emitted to indicate a change of the
         network state
@@ -193,7 +193,7 @@
     preferencesChanged = pyqtSignal()
     reloadAPIs = pyqtSignal()
     showMenu = pyqtSignal(str, QMenu)
-    masterPasswordChanged = pyqtSignal(str, str)
+    mainPasswordChanged = pyqtSignal(str, str)
     onlineStateChanged = pyqtSignal(bool)
 
     maxFilePathLen = 100
@@ -7120,8 +7120,8 @@
             self.__configurationDialog.preferencesChanged.connect(
                 self.__preferencesChanged
             )
-            self.__configurationDialog.masterPasswordChanged.connect(
-                self.__masterPasswordChanged
+            self.__configurationDialog.mainPasswordChanged.connect(
+                self.__mainPasswordChanged
             )
             self.__configurationDialog.show()
             if pageName is not None:
@@ -7265,16 +7265,18 @@
 
         self.preferencesChanged.emit()
 
-    def __masterPasswordChanged(self, oldPassword, newPassword):
-        """
-        Private slot to handle the change of the master password.
-
-        @param oldPassword current master password (string)
-        @param newPassword new master password (string)
+    def __mainPasswordChanged(self, oldPassword, newPassword):
+        """
+        Private slot to handle the change of the main password.
+
+        @param oldPassword current main password
+        @type str
+        @param newPassword new main password
+        @type str
         """
         from eric7 import Globals
 
-        self.masterPasswordChanged.emit(oldPassword, newPassword)
+        self.mainPasswordChanged.emit(oldPassword, newPassword)
         Preferences.convertPasswords(oldPassword, newPassword)
         variant = Globals.getWebBrowserSupport()
         if variant == "QtWebEngine":
@@ -7283,8 +7285,8 @@
             )
 
             pwManager = PasswordManager()
-            pwManager.masterPasswordChanged(oldPassword, newPassword)
-        Utilities.crypto.changeRememberedMaster(newPassword)
+            pwManager.mainPasswordChanged(oldPassword, newPassword)
+        Utilities.crypto.changeRememberedMain(newPassword)
 
     def __reloadAPIs(self):
         """

eric ide

mercurial